Class: UltimateTurboModal::Railtie

Inherits:
Rails::Railtie
  • Object
show all
Defined in:
lib/ultimate_turbo_modal/railtie.rb

Class Method Summary collapse

Class Method Details

.stylesheets_pathObject

Absolute path to the stylesheets shipped with the gem. Exposed so that apps and tooling can locate ultimate_turbo_modal.css without guessing.



13
14
15
# File 'lib/ultimate_turbo_modal/railtie.rb', line 13

def self.stylesheets_path
  File.expand_path("../../app/assets/stylesheets", __dir__)
end