Module: UltimateTurboModal::Flavors
- Defined in:
- lib/generators/ultimate_turbo_modal/templates/flavors/custom.rb,
lib/generators/ultimate_turbo_modal/templates/flavors/vanilla.rb,
lib/generators/ultimate_turbo_modal/templates/flavors/tailwind.rb
Overview
Tailwind CSS v4
Group selectors are scoped with the named groups ‘group/utmr-modal` and `group/utmr-drawer` so that when a modal stacks on top of an open drawer, the inner modal’s transition styles don’t pick up the outer drawer’s ‘data-entered` state (which would prevent the modal from animating out).